summaryrefslogtreecommitdiffstats
path: root/client/components/settings/connectionMethod.js
diff options
context:
space:
mode:
Diffstat (limited to 'client/components/settings/connectionMethod.js')
-rw-r--r--client/components/settings/connectionMethod.js22
1 files changed, 11 insertions, 11 deletions
diff --git a/client/components/settings/connectionMethod.js b/client/components/settings/connectionMethod.js
index 4983a3ef..3d5cfd76 100644
--- a/client/components/settings/connectionMethod.js
+++ b/client/components/settings/connectionMethod.js
@@ -1,20 +1,20 @@
Template.connectionMethod.onCreated(function() {
- this.connectionMethods = new ReactiveVar([]);
+ this.authenticationMethods = new ReactiveVar([]);
- Meteor.call('getConnectionsEnabled', (_, result) => {
+ Meteor.call('getAuthenticationsEnabled', (_, result) => {
if (result) {
// TODO : add a management of different languages
// (ex {value: ldap, text: TAPi18n.__('ldap', {}, T9n.getLanguage() || 'en')})
- this.connectionMethods.set([
- {value: 'default'},
- // Gets only the connection methods availables
+ this.authenticationMethods.set([
+ {value: 'password'},
+ // Gets only the authentication methods availables
...Object.entries(result).filter((e) => e[1]).map((e) => ({value: e[0]})),
]);
}
// If only the default authentication available, hides the select boxe
- const content = $('.at-form-connection');
- if (!(this.connectionMethods.get().length > 1)) {
+ const content = $('.at-form-authentication');
+ if (!(this.authenticationMethods.get().length > 1)) {
content.hide();
} else {
content.show();
@@ -24,11 +24,11 @@ Template.connectionMethod.onCreated(function() {
Template.connectionMethod.onRendered(() => {
// Moves the select boxe in the first place of the at-pwd-form div
- $('.at-form-connection').detach().prependTo('.at-pwd-form');
+ $('.at-form-authentication').detach().prependTo('.at-pwd-form');
});
Template.connectionMethod.helpers({
- connections() {
- return Template.instance().connectionMethods.get();
+ authentications() {
+ return Template.instance().authenticationMethods.get();
},
-});
+}); \ No newline at end of file